Class: Ghundle::Source::Common
- Inherits:
-
Object
- Object
- Ghundle::Source::Common
- Defined in:
- lib/ghundle/source/common.rb
Overview
A descendant of Source::Common is a source that can be used to fetch a hook from a remote location into a local path. Look at the various children of this class to understand its usage better.
Instance Method Summary collapse
-
#fetch(destination_path) ⇒ Object
Fetches the source into the local path, making it ready for execution.
-
#fetched?(destination_path) ⇒ Boolean
Checks if the source was already extracted to the given path.
-
#hook_name ⇒ Object
Gets the name of the hook based on the url/path it’s given.
-
#metadata ⇒ Object
Returns this source’s metadata object.
Instance Method Details
#fetch(destination_path) ⇒ Object
Fetches the source into the local path, making it ready for execution. Returns a Source::Local that can be used to access its data.
20 21 22 |
# File 'lib/ghundle/source/common.rb', line 20 def fetch(destination_path) raise NotImplementedError end |
#fetched?(destination_path) ⇒ Boolean
Checks if the source was already extracted to the given path.
25 26 27 |
# File 'lib/ghundle/source/common.rb', line 25 def fetched?(destination_path) raise NotImplementedError end |
#hook_name ⇒ Object
Gets the name of the hook based on the url/path it’s given
9 10 11 |
# File 'lib/ghundle/source/common.rb', line 9 def hook_name raise NotImplementedError end |
#metadata ⇒ Object
Returns this source’s metadata object.
14 15 16 |
# File 'lib/ghundle/source/common.rb', line 14 def raise NotImplementedError end |